#!/bin/bash
accumsize=$(($1))
scoredir=test-s${accumsize}
double=$(($accumsize*2))

shopt -s lastpipe  # this supposedly forces all commands to one shell which allows "read"ing pipes.

# Sort the candidates
sort -g -k1 -k2 -k3 "${scoredir}/maxiter-xs-s${accumsize}.out" >"${scoredir}/sorted-xs-s${accumsize}.out"
sort -g -k1 -k2 -k3 "${scoredir}/maxiter-xo-s${accumsize}.out" >"${scoredir}/sorted-xo-s${accumsize}.out"


function extract_score {
	local temp="    "
	if [ -f ${1} ]; then
		grep "length=" ${1} | tail -n1 | read length value suffix line
		printf -v temp "%3d${suffix:0:1}" ${value}
	fi
	printf "${temp^^}"
}


printf "\n\n    Xorshift${double}+ PractRand Score Table\n\nCombination   Word  Byte3  Byte2  Byte1   Bit\n===============================================\n" | tee "PRscore-s${accumsize}.txt"

# Xorshift - Read one candidate line at a time from the file, picking out each 'a' 'b' 'c' combination
while IFS=", \t" read a b c line
do
# Convert to integers
	a=$(($a))
	b=$(($b))
	c=$(($c))

# extract the candidate score for each test variant
	word=$( extract_score "${scoredir}/PRscore-xs-s${accumsize}-a${a}b${b}c${c}.out" )
	byte3=$( extract_score "${scoredir}/PRscore-xs-s${accumsize}byte$((${accumsize}-8))-a${a}b${b}c${c}.out" )
	byte2=$( extract_score "${scoredir}/PRscore-xs-s${accumsize}byte$(((${accumsize}-8)/2))-a${a}b${b}c${c}.out" )
	byte1=$( extract_score "${scoredir}/PRscore-xs-s${accumsize}byte1-a${a}b${b}c${c}.out" )
	bit=$( extract_score "${scoredir}/PRscore-xs-s${accumsize}bit-a${a}b${b}c${c}.out" )

# Output the score
	printf " [%2d %2d %2d]   ${word}   ${byte3}   ${byte2}   ${byte1}   ${bit}\n" ${a} ${b} ${c} | tee -a "PRscore-s${accumsize}.txt"

done < "${scoredir}/sorted-xs-s${accumsize}.out"


printf "\n\n    Xoroshiro${double}+ PractRand Score Table\n\nCombination   Word  Byte3  Byte2  Byte1   Bit\n===============================================\n" | tee -a "PRscore-s${accumsize}.txt"

# Xoroshiro - Read one candidate line at a time from the file, picking out each 'a' 'b' 'c' combination
while IFS=", \t" read a b c line
do
# Convert to integers
	a=$(($a))
	b=$(($b))
	c=$(($c))

# extract the candidate score for each test variant
	word=$( extract_score "${scoredir}/PRscore-xo-s${accumsize}-a${a}b${b}c${c}.out" )
	byte3=$( extract_score "${scoredir}/PRscore-xo-s${accumsize}byte$((${accumsize}-8))-a${a}b${b}c${c}.out" )
	byte2=$( extract_score "${scoredir}/PRscore-xo-s${accumsize}byte$(((${accumsize}-8)/2))-a${a}b${b}c${c}.out" )
	byte1=$( extract_score "${scoredir}/PRscore-xo-s${accumsize}byte1-a${a}b${b}c${c}.out" )
	bit=$( extract_score "${scoredir}/PRscore-xo-s${accumsize}bit-a${a}b${b}c${c}.out" )

# Output the score
	printf " [%2d %2d %2d]   ${word}   ${byte3}   ${byte2}   ${byte1}   ${bit}\n" ${a} ${b} ${c} | tee -a "PRscore-s${accumsize}.txt"

done < "${scoredir}/sorted-xo-s${accumsize}.out"
